<?php
/**
 * Define some custom classes for uncode.
 * 
 * https://codex.wordpress.org/Class_Reference/WP_Customize_Control
 *
 * @package AccessPress Themes
 * @subpackage Uncode Lite
 * @since 1.0.0
 */

if ( class_exists( 'WP_Customize_Control' ) ) {

	/**
     * Switch button customize control.
     *
     * @since 1.0.0
     * @access public
     */
    class Uncode_Lite_Customize_Switch_Control extends WP_Customize_Control {

    	/**
	     * The type of customize control being rendered.
	     *
	     * @since  1.0.0
	     * @access public
	     * @var    string
	     */
		public $type = 'switch';
		/**
	     * Displays the control content.
	     *
	     * @since  1.0.0
	     * @access public
	     * @return void
	     */
		public function render_content() { ?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<div class="description customize-control-description"><?php echo esc_html( $this->description ); ?></div>
		        <div class="switch_options">
		        	<?php 
		        		$show_choices = $this->choices;
		        		foreach ( $show_choices as $key => $value ) {
		        			echo '<span class="switch_part '.esc_attr($key).'" data-switch="'.esc_attr($key).'">'. esc_attr($value).'</span>';
		        		}
		        	?>
                  	<input type="hidden" id="ap_switch_option" <?php $this->link(); ?> value="<?php echo esc_attr($this->value()); ?>" />
                </div>
            </label>
	<?php
		}
	}

	/**
	 * A class to create a dropdown for all categories in your wordpress site
	 *
	 * @since 1.0.0
	 * @access public
	 */
	class Uncode_Lite_Customize_Category_Control extends WP_Customize_Control {
		
		/**
		 * Render the control's content.
		 *
		 * @return HTML
		 * @since 1.0.0
		 */
		public function render_content() {
			$dropdown = wp_dropdown_categories(
				array(
					'name'              => '_customize-dropdown-categories-' . $this->id,
					'echo'              => 0,
					'show_option_none'  => esc_html__( '--Select Category--', 'uncode-lite' ),
					'option_none_value' => '0',
					'selected'          => $this->value(),
				)
			);

			// Hackily add in the data link parameter.
			$dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );

			printf(
				'<label class="customize-control-select"><span class="customize-control-title">%s</span><span class="description customize-control-description">%s</span> %s </label>',
				$this->label,
				$this->description,
				$dropdown
			);
		}
	}
	

	/**
	 * A class to create a list of icons in customizer field
	 *
	 * @since 1.0.0
	 * @access public
	 */
	class Uncode_Lite_Customize_Icons_Control extends WP_Customize_Control {

		/**
	     * The type of customize control being rendered.
	     *
	     * @since  1.0.0
	     * @access public
	     * @var    string
	     */
		public $type = 'uncode_lite_icons';

		/**
	     * Displays the control content.
	     *
	     * @since  1.0.0
	     * @access public
	     * @return void
	     */
		public function render_content() {

			$saved_icon_value = $this->value(); ?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
				<div class="ap-customize-icons">
					<div class="selected-icon-preview"><?php if( !empty( $saved_icon_value ) ) { echo '<i class="fa '. esc_attr($saved_icon_value) .'"></i>'; } ?></div>
					<ul class="icons-list-wrapper">
						<?php 
							$uncode_lite_icons_list = uncode_lite_icons_array();
							foreach ( $uncode_lite_icons_list as $key => $icon_value ) {
								if( $saved_icon_value == $icon_value ) {
									echo '<li class="selected"><i class="fa '. esc_attr($icon_value) .'"></i></li>';
								} else {
									echo '<li><i class="fa '. esc_attr($icon_value) .'"></i></li>';
								}
							}
						?>
					</ul>
					<input type="hidden" class="ap-icon-value" value="" <?php $this->link(); ?>>
				</div>

			</label>
	<?php
		}
	}

	/**
	* Multiple checkbox customize control class.
	*
	* @since  1.0.0
	* @access public
	*/
	class Uncode_Lite_Customize_Control_Checkbox_Multiple extends WP_Customize_Control {

	   /**
	    * The type of customize control being rendered.
	    *
	    * @since  1.0.0
	    * @access public
	    * @var    string
	    */
	   public $type = 'checkbox-multiple';

	   /**
	    * Displays the control content.
	    *
	    * @since  1.0.0
	    * @access public
	    * @return void
	    */
	   public function render_content() {

	       if ( empty( $this->choices ) )
	           return; ?>

	       <?php if ( !empty( $this->label ) ) : ?>
	           <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	       <?php endif; ?>

	       <?php if ( !empty( $this->description ) ) : ?>
	           <span class="description customize-control-description"><?php echo esc_html($this->description); ?></span>
	       <?php endif; ?>

	       <?php $multi_values = !is_array( $this->value() ) ? explode( ',', $this->value() ) : $this->value(); ?>

	       <ul>
	           <?php foreach ( $this->choices as $value => $label ) : ?>

	               <li>
	                   <label>
	                       <input type="checkbox" value="<?php echo esc_attr( $value ); ?>" <?php checked( in_array( $value, $multi_values ) ); ?> /> 
	                       <?php echo esc_html( $label ); ?>
	                   </label>
	               </li>

	           <?php endforeach; ?>
	       </ul>

	       <input type="hidden" <?php $this->link(); ?> value="<?php echo esc_attr( implode( ',', $multi_values ) ); ?>" />
	   <?php }
	}

	/**
	 * A class to create a option separator in customizer section 
	 *
	 *@since 1.0.0
	 */
	class uncode_lite_Customize_Section_Separator extends WP_Customize_Control {

		public $type = 'uncode_lite_separator';

		public function render_content() { ?>
			<div class="serviceswrap">
				<label>
					<span class="sep-title"><?php echo esc_html( $this->label ); ?></span>
				</label>
			</div>
	    <?php }
	}

	/**
     * Theme info
     */
    class Uncode_Info_Custom_Control extends WP_Customize_Control {
        public function render_content(){

            $important_links = array(
                'demo' => array(
                   'link' => esc_url( 'http://accesspressthemes.com/theme-demos/?theme=uncode' ),
                   'text' => __( 'View Demo', 'uncode-lite' ),
                ),
                'documentation' => array(
                   'link' => esc_url( 'http://doc.accesspressthemes.com/uncode/' ),
                   'text' => __( 'Documentation', 'uncode-lite' ),
                ),
                'theme-info' => array(
                   'link' => esc_url( 'https://accesspressthemes.com/wordpress-themes/uncode/' ),
                   'text' => __( 'Theme Info', 'uncode-lite' ),
                ),
                'support' => array(
                   'link' => esc_url( 'https://accesspressthemes.com/support/forum/themes/free-themes/uncode/' ),
                   'text' => __( 'Support', 'uncode-lite' ),
                ),
                'rating' => array(
                   'link' => esc_url( 'https://wordpress.org/support/theme/uncode-lite/reviews/#new-post' ),
                   'text' => __( 'Rate This Theme', 'uncode-lite' ),
                ),
                'resources' => array(
                   'link' => esc_url( 'http://wpall.club/' ),
                   'text' => __( 'More WordPress Resources', 'uncode-lite' ),
                ),
            );
            foreach ( $important_links as $important_link ) {
                echo '<p><a target="_blank" href="' . $important_link['link'] . '" >' . esc_html( $important_link['text'] ) . ' </a></p>';
            }
        ?>
        	<label>
        	    <h2 class="customize-title"><?php echo esc_html( $this->label ); ?></h2>
        	    <span class="customize-text_editor_desc">                 
        	        <ul class="admin-pro-feature-list">
        	        	<li><span><?php _e('One Click Demo Import','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Unlimited theme colors','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Advanced Typography Option','uncode-lite'); ?> </span></li>
						<li><span><?php _e('4 Different Page & Post Layouts','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Re-Order All Home Page Section','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Advance Breadcrumb setting','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Web Page Layout Options','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Inbuilt Unlimited sliders','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Revolution Slider','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Static Banner Images Options','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Flexible Header Settings','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Custom Shortcodes','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Background Configuration','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Cross browser compatible','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Fully SEO optimized','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Fast loading','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Translation Ready','uncode-lite'); ?> </span></li>
						<li><span><?php _e('Live Preview in Customizer','uncode-lite'); ?> </span></li>
        	        </ul>
        	        <?php $enlighten_pro_link = 'https://accesspressthemes.com/wordpress-themes/enlighten-pro/'; ?>
        	        <a href="<?php echo esc_url($enlighten_pro_link); ?>" class="button button-primary buynow" target="_blank"><?php _e('Buy Now','uncode-lite'); ?></a>
        	    </span>
        	</label>
        <?php
        }
    }

    /**
     * Pro customizer section.
     *
     * @since  1.0.0
     * @access public
     */
    class Uncode_Customize_Section_Pro extends WP_Customize_Section {

        /**
         * The type of customize section being rendered.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $type = 'uncode-pro';

        /**
         * Custom button text to output.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $pro_text = '';

        /**
         * Custom pro button URL.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $pro_url = '';

        /**
         * Add custom parameters to pass to the JS via JSON.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        public function json() {
            $json = parent::json();
            $json['pro_text'] = $this->pro_text;
            $json['pro_url']  = esc_url( $this->pro_url );
            return $json;
        }

        /**
         * Outputs the Underscore.js template.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        protected function render_template() { ?>

            <li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
                <h3 class="accordion-section-title">
                    {{ data.title }}
                    <# if ( data.pro_text && data.pro_url ) { #>
                        <a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
                    <# } #>
                </h3>
            </li>
        <?php }
    }
}
